@@ -24,7 +24,7 @@ const our $ADDRESS_POSTAL_CODE  => 1 << 14;
 const our $ADDRESS_NEIGHBORHOOD => 1 << 15;
 const our $ADDRESS_ALL          => (1 << 16) - 1;
 
-our $VERSION     = '0.05';
+our $VERSION     = '0.06';
 our %EXPORT_TAGS = ( 'all' => [qw/
     expand_address
     parse_address
@@ -50,7 +50,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 XSLoader::load('Geo::libpostal', $VERSION);
 
 # cleanup libpostal
-END { _teardown() }
+#END { _teardown() }
 1;
 __END__
 =encoding utf8
@@ -93,8 +93,7 @@ libpostal is a C library for parsing/normalizing international street addresses.
   my @ny_addresses = expand_address('120 E 96th St New York');
   my @fr_addresses = expand_address('Quatre vingt douze R. de l\'Église');
 
-Takes an address string and returns a list of known variants. Useful for
-normalization. Accepts many boolean options:
+Takes an address string and returns a list of known variants. Useful for normalization. Accepts many boolean options:
 
   expand_address('120 E 96th St New York',
       latin_ascii => 1,
@@ -117,7 +116,7 @@ normalization. Accepts many boolean options:
       roman_numerals => 1,
   );
 
-B<Warning>: old versions of libpostal L<segfault|https://github.com/openvenues/libpostal/issues/79> if all options are set to false.
+B<Warning>: old versions of libpostal L<segfault|https://github.com/openvenues/libpostal/issues/79> if all options are set to false. This C<Geo::libpostal> includes a unit test for this.
 
 Also accepts an arrayref of language codes per L<ISO 639-1|https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes>:
 
@@ -125,7 +124,7 @@ Also accepts an arrayref of language codes per L<ISO 639-1|https://en.wikipedia.
 
 This is useful if you are normalizing addresses in multiple languages.
 
-Finally C<expand_address> accepts an option for which address C<components> to expand. This a 16bit integer bitmask. These constants are exported with the C<:all> tag:
+Finally C<expand_address> accepts an option for which address C<components> to expand. This is a 16 bit integer bitmask. These constants are exported with the C<:all> tag:
 
   $ADDRESS_NONE
   $ADDRESS_ANY
@@ -197,12 +196,28 @@ C<expand_address> will C<die> on C<undef> and empty addresses, odd numbers of op
 
 Will C<die> on C<undef> and empty addresses. Exported on request.
 
-C<parse_address()> may return L<duplicate labels|https://github.com/openvenues/libpostal/issues/27> for invalid addresses
+C<parse_address> may return L<duplicate labels|https://github.com/openvenues/libpostal/issues/27> for invalid addresses
 strings.
 
 =head1 WARNING
 
-libpostal uses C<setup()> and C<teardown()> functions. Setup is lazily loaded. Teardown occurs in an C<END> block automatically. C<Geo::libpostal> will C<die> if C<expand_address> or C<parse_address> is called after teardown.
+libpostal uses C<setup> and C<teardown> functions. Setup is lazily loaded. Teardown occurs in an C<END> block automatically.
+
+=over 4
+
+=item *
+
+Old versions of libpostal C<Geo::libpostal> will L<segfault|https://github.com/openvenues/libpostal/issues/82> if C<_teardown()> is called twice (this module includes a unit test for this).
+
+=item *
+
+If C<expand_address> or C<parse_address> is called after teardown, old versions of libpostal will L<error|https://github.com/openvenues/libpostal/pull/86> (this module includes a unit test for this too).
+
+=item *
+
+libpostal is not L<thread-safe|https://github.com/openvenues/libpostal/issues/34>.
+
+=back
 
 =head1 EXTERNAL DEPENDENCIES
 
